# 管理服务

本章介绍如何使用systemd进行系统和服务管理。
<!-- TOC -->

- [管理服务](#管理服务)
    - [简介](#简介)
        - [概念介绍](#概念介绍)
    - [特性说明](#特性说明)
        - [更快的启动速度](#更快的启动速度)
        - [提供按需启动能力](#提供按需启动能力)
        - [采用cgroup特性跟踪和管理进程的生命周期](#采用cgroup特性跟踪和管理进程的生命周期)
        - [启动挂载点和自动挂载的管理](#启动挂载点和自动挂载的管理)
        - [实现事务性依赖关系管理](#实现事务性依赖关系管理)
        - [与SysV初始化脚本兼容](#与sysv初始化脚本兼容)
        - [能够对系统进行快照和恢复](#能够对系统进行快照和恢复)
    - [管理系统服务](#管理系统服务)
        - [sysvinit命令和systemd命令](#sysvinit命令和systemd命令)
        - [显示所有当前服务](#显示所有当前服务)
        - [显示服务状态](#显示服务状态)
        - [运行服务](#运行服务)
        - [关闭服务](#关闭服务)
        - [重启服务](#重启服务)
        - [启用服务](#启用服务)
        - [禁用服务](#禁用服务)
    - [改变运行级别](#改变运行级别)
        - [Target和运行级别](#target和运行级别)
        - [查看系统默认启动目标](#查看系统默认启动目标)
        - [查看当前系统所有的启动目标](#查看当前系统所有的启动目标)
        - [改变默认目标](#改变默认目标)
        - [改变当前目标](#改变当前目标)
        - [切换到救援模式](#切换到救援模式)
        - [切换到紧急模式](#切换到紧急模式)
    - [关闭、暂停和休眠系统](#关闭暂停和休眠系统)
        - [systemctl命令](#systemctl命令)
        - [关闭系统](#关闭系统)
        - [重启系统](#重启系统)
        - [使系统待机](#使系统待机)
        - [使系统休眠](#使系统休眠)

<!-- /TOC -->

## 简介

systemd是在Linux下，与SysV和LSB初始化脚本兼容的系统和服务管理器。systemd使用socket和D-Bus来开启服务，提供基于守护进程的按需启动策略，支持快照和系统状态恢复，维护挂载和自挂载点，实现了各服务间基于从属关系的一个更为精细的逻辑控制，拥有更高的并行性能。

### 概念介绍

systemd开启和监督整个系统是基于unit的概念。unit是由一个与配置文件对应的名字和类型组成的（例如：avahi.service unit有一个具有相同名字的配置文件，是守护进程Avahi的一个封装单元）。unit有多重类型，如[表1](#zh-cn_topic_0151921012_t2dcb6d973cc249ed9ccd56729751ca6b)所示。

**表 1**  unit说明

<a name="zh-cn_topic_0151921012_t2dcb6d973cc249ed9ccd56729751ca6b"></a>
<table><thead align="left"><tr id="zh-cn_topic_0151921012_r7b42846c4fae43e7884a3f020f608fe2"><th class="cellrowborder" valign="top" width="23.18%" id="mcps1.2.4.1.1"><p id="zh-cn_topic_0151921012_ab281691f1f2b4cc1bbe493047d2362d9"><a name="zh-cn_topic_0151921012_ab281691f1f2b4cc1bbe493047d2362d9"></a><a name="zh-cn_topic_0151921012_ab281691f1f2b4cc1bbe493047d2362d9"></a>unit名称</p>
</th>

<th class="cellrowborder" valign="top" width="20.36%" id="mcps1.2.4.1.2"><p id="zh-cn_topic_0151921012_a0f7c1823e26547e796c1641f97c33fdd"><a name="zh-cn_topic_0151921012_a0f7c1823e26547e796c1641f97c33fdd"></a><a name="zh-cn_topic_0151921012_a0f7c1823e26547e796c1641f97c33fdd"></a>后缀名</p>
</th>

<th class="cellrowborder" valign="top" width="56.46%" id="mcps1.2.4.1.3"><p id="zh-cn_topic_0151921012_a60a2db60a7044830b7484a6acc33be0e"><a name="zh-cn_topic_0151921012_a60a2db60a7044830b7484a6acc33be0e"></a><a name="zh-cn_topic_0151921012_a60a2db60a7044830b7484a6acc33be0e"></a>描述</p>
</th>

</tr>

</thead>
<tbody><tr id="zh-cn_topic_0151921012_r792e4f30a76a4d1a87472bf69f4208ab"><td class="cellrowborder" valign="top" width="23.18%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151921012_a920c3978e086448eab26a0c108b3fc4b"><a name="zh-cn_topic_0151921012_a920c3978e086448eab26a0c108b3fc4b"></a><a name="zh-cn_topic_0151921012_a920c3978e086448eab26a0c108b3fc4b"></a>Service unit</p>
</td>

<td class="cellrowborder" valign="top" width="20.36%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151921012_ab53b8d9e50b3496f9c42ac71130179a8"><a name="zh-cn_topic_0151921012_ab53b8d9e50b3496f9c42ac71130179a8"></a><a name="zh-cn_topic_0151921012_ab53b8d9e50b3496f9c42ac71130179a8"></a>.service</p>
</td>

<td class="cellrowborder" valign="top" width="56.46%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151921012_a4021f8a9f8ac44889df66eb405ba8707"><a name="zh-cn_topic_0151921012_a4021f8a9f8ac44889df66eb405ba8707"></a><a name="zh-cn_topic_0151921012_a4021f8a9f8ac44889df66eb405ba8707"></a>系统服务。</p>
</td>

</tr>

<tr id="zh-cn_topic_0151921012_r1dc46642b82640b8ba50c274a71c0115"><td class="cellrowborder" valign="top" width="23.18%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151921012_acc7293f71641476d866484f4b4e2e17d"><a name="zh-cn_topic_0151921012_acc7293f71641476d866484f4b4e2e17d"></a><a name="zh-cn_topic_0151921012_acc7293f71641476d866484f4b4e2e17d"></a>Target unit</p>
</td>

<td class="cellrowborder" valign="top" width="20.36%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151921012_a972c16ba24e44039a202a8a8b500cf0d"><a name="zh-cn_topic_0151921012_a972c16ba24e44039a202a8a8b500cf0d"></a><a name="zh-cn_topic_0151921012_a972c16ba24e44039a202a8a8b500cf0d"></a>.target</p>
</td>

<td class="cellrowborder" valign="top" width="56.46%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151921012_a794b9638ea42413087672632eb3ecc9b"><a name="zh-cn_topic_0151921012_a794b9638ea42413087672632eb3ecc9b"></a><a name="zh-cn_topic_0151921012_a794b9638ea42413087672632eb3ecc9b"></a>一组systemd units。</p>
</td>

</tr>

<tr id="zh-cn_topic_0151921012_rf862dcc0891e4292b214e743020fad44"><td class="cellrowborder" valign="top" width="23.18%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151921012_aa36d2a004680460eb77cd61abfda11ff"><a name="zh-cn_topic_0151921012_aa36d2a004680460eb77cd61abfda11ff"></a><a name="zh-cn_topic_0151921012_aa36d2a004680460eb77cd61abfda11ff"></a>Automount unit</p>
</td>

<td class="cellrowborder" valign="top" width="20.36%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151921012_aea349872c8b64346aca1fd99b220ade4"><a name="zh-cn_topic_0151921012_aea349872c8b64346aca1fd99b220ade4"></a><a name="zh-cn_topic_0151921012_aea349872c8b64346aca1fd99b220ade4"></a>.automount</p>
</td>

<td class="cellrowborder" valign="top" width="56.46%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151921012_a2752debc211c4c2a8d2dec5df410cd5f"><a name="zh-cn_topic_0151921012_a2752debc211c4c2a8d2dec5df410cd5f"></a><a name="zh-cn_topic_0151921012_a2752debc211c4c2a8d2dec5df410cd5f"></a>文件系统挂载点。</p>
</td>

</tr>

<tr id="zh-cn_topic_0151921012_r151262203bbd41dfbcf6450b977adcd8"><td class="cellrowborder" valign="top" width="23.18%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151921012_a63ad759ddc924457ae160f5ef2134665"><a name="zh-cn_topic_0151921012_a63ad759ddc924457ae160f5ef2134665"></a><a name="zh-cn_topic_0151921012_a63ad759ddc924457ae160f5ef2134665"></a>Device unit</p>
</td>

<td class="cellrowborder" valign="top" width="20.36%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151921012_a1d72eda1c2e14a5ca5b4bbd3d1e04df2"><a name="zh-cn_topic_0151921012_a1d72eda1c2e14a5ca5b4bbd3d1e04df2"></a><a name="zh-cn_topic_0151921012_a1d72eda1c2e14a5ca5b4bbd3d1e04df2"></a>.device</p>
</td>

<td class="cellrowborder" valign="top" width="56.46%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151921012_a17fb3dcba5df47e9bd6dcadb1fdd0570"><a name="zh-cn_topic_0151921012_a17fb3dcba5df47e9bd6dcadb1fdd0570"></a><a name="zh-cn_topic_0151921012_a17fb3dcba5df47e9bd6dcadb1fdd0570"></a>内核识别的设备文件。</p>
</td>

</tr>

<tr id="zh-cn_topic_0151921012_re7d8c6541280475e900e3b336b9af327"><td class="cellrowborder" valign="top" width="23.18%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151921012_a4950ed734138459c83be23229b5f3d6a"><a name="zh-cn_topic_0151921012_a4950ed734138459c83be23229b5f3d6a"></a><a name="zh-cn_topic_0151921012_a4950ed734138459c83be23229b5f3d6a"></a>Mount unit</p>
</td>

<td class="cellrowborder" valign="top" width="20.36%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151921012_ab745de23d809475d9c5c9e20e81066d1"><a name="zh-cn_topic_0151921012_ab745de23d809475d9c5c9e20e81066d1"></a><a name="zh-cn_topic_0151921012_ab745de23d809475d9c5c9e20e81066d1"></a>.mount</p>
</td>

<td class="cellrowborder" valign="top" width="56.46%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151921012_a689c3d6fa3124b61af6546d7ff4e5f42"><a name="zh-cn_topic_0151921012_a689c3d6fa3124b61af6546d7ff4e5f42"></a><a name="zh-cn_topic_0151921012_a689c3d6fa3124b61af6546d7ff4e5f42"></a>文件系统挂载点。</p>
</td>

</tr>

<tr id="zh-cn_topic_0151921012_r1c9abcac0409405390c79d039efd1f73"><td class="cellrowborder" valign="top" width="23.18%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151921012_a105f139cb99a424ebf6668c409fbfd10"><a name="zh-cn_topic_0151921012_a105f139cb99a424ebf6668c409fbfd10"></a><a name="zh-cn_topic_0151921012_a105f139cb99a424ebf6668c409fbfd10"></a>Path unit</p>
</td>

<td class="cellrowborder" valign="top" width="20.36%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151921012_af1454bde836a4118b58341b586e1770a"><a name="zh-cn_topic_0151921012_af1454bde836a4118b58341b586e1770a"></a><a name="zh-cn_topic_0151921012_af1454bde836a4118b58341b586e1770a"></a>.path</p>
</td>

<td class="cellrowborder" valign="top" width="56.46%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151921012_ace9baa2479c64f97abb493519474df4d"><a name="zh-cn_topic_0151921012_ace9baa2479c64f97abb493519474df4d"></a><a name="zh-cn_topic_0151921012_ace9baa2479c64f97abb493519474df4d"></a>在一个文件系统中的文件或目录。</p>
</td>

</tr>

<tr id="zh-cn_topic_0151921012_r110ad4c541c241ac816e2827ef85c035"><td class="cellrowborder" valign="top" width="23.18%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151921012_aaa9d61a1976b4c399f8d26feee1f8a9a"><a name="zh-cn_topic_0151921012_aaa9d61a1976b4c399f8d26feee1f8a9a"></a><a name="zh-cn_topic_0151921012_aaa9d61a1976b4c399f8d26feee1f8a9a"></a>Scope unit</p>
</td>

<td class="cellrowborder" valign="top" width="20.36%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151921012_ad16b81af817345d3822330091c783398"><a name="zh-cn_topic_0151921012_ad16b81af817345d3822330091c783398"></a><a name="zh-cn_topic_0151921012_ad16b81af817345d3822330091c783398"></a>.scope</p>
</td>

<td class="cellrowborder" valign="top" width="56.46%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151921012_a4c7749fd392348668a0cb1b25cbac70d"><a name="zh-cn_topic_0151921012_a4c7749fd392348668a0cb1b25cbac70d"></a><a name="zh-cn_topic_0151921012_a4c7749fd392348668a0cb1b25cbac70d"></a>外部创建的进程。</p>
</td>

</tr>

<tr id="zh-cn_topic_0151921012_r6f7302c1ed8244e291ffa0ae08a3b27c"><td class="cellrowborder" valign="top" width="23.18%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151921012_ab41ebb369a5c47598601bd96ca5d95af"><a name="zh-cn_topic_0151921012_ab41ebb369a5c47598601bd96ca5d95af"></a><a name="zh-cn_topic_0151921012_ab41ebb369a5c47598601bd96ca5d95af"></a>Slice unit</p>
</td>

<td class="cellrowborder" valign="top" width="20.36%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151921012_a18c465ebe76c4ffb8950064ee9a62858"><a name="zh-cn_topic_0151921012_a18c465ebe76c4ffb8950064ee9a62858"></a><a name="zh-cn_topic_0151921012_a18c465ebe76c4ffb8950064ee9a62858"></a>.slice</p>
</td>

<td class="cellrowborder" valign="top" width="56.46%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151921012_a060e385703ed49a0bbb993f60520a6dd"><a name="zh-cn_topic_0151921012_a060e385703ed49a0bbb993f60520a6dd"></a><a name="zh-cn_topic_0151921012_a060e385703ed49a0bbb993f60520a6dd"></a>一组用于管理系统进程分层组织的units。</p>
</td>

</tr>

<tr id="zh-cn_topic_0151921012_r464fbcf4d5b04ed29b11f52b150531ab"><td class="cellrowborder" valign="top" width="23.18%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151921012_a8c0ed4656ebb4a10b1fcbce2ce396683"><a name="zh-cn_topic_0151921012_a8c0ed4656ebb4a10b1fcbce2ce396683"></a><a name="zh-cn_topic_0151921012_a8c0ed4656ebb4a10b1fcbce2ce396683"></a>Snapshot unit</p>
</td>

<td class="cellrowborder" valign="top" width="20.36%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151921012_a2815b0c797784a9e95de60f614a683a7"><a name="zh-cn_topic_0151921012_a2815b0c797784a9e95de60f614a683a7"></a><a name="zh-cn_topic_0151921012_a2815b0c797784a9e95de60f614a683a7"></a>.snapshot</p>
</td>

<td class="cellrowborder" valign="top" width="56.46%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151921012_adf4318e96e0d47efbad6c438a124d924"><a name="zh-cn_topic_0151921012_adf4318e96e0d47efbad6c438a124d924"></a><a name="zh-cn_topic_0151921012_adf4318e96e0d47efbad6c438a124d924"></a>systemd manager的保存状态。</p>
</td>

</tr>

<tr id="zh-cn_topic_0151921012_rf411a13d70a64af0913d1403098c35f4"><td class="cellrowborder" valign="top" width="23.18%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151921012_a20f3e23c829a4337a8fb5fc64b628fda"><a name="zh-cn_topic_0151921012_a20f3e23c829a4337a8fb5fc64b628fda"></a><a name="zh-cn_topic_0151921012_a20f3e23c829a4337a8fb5fc64b628fda"></a>Socket unit</p>
</td>

<td class="cellrowborder" valign="top" width="20.36%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151921012_a4dde23a95c7f49649608dea395226e51"><a name="zh-cn_topic_0151921012_a4dde23a95c7f49649608dea395226e51"></a><a name="zh-cn_topic_0151921012_a4dde23a95c7f49649608dea395226e51"></a>.socket</p>
</td>

<td class="cellrowborder" valign="top" width="56.46%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151921012_a0b30893d3da240388885a50af44269db"><a name="zh-cn_topic_0151921012_a0b30893d3da240388885a50af44269db"></a><a name="zh-cn_topic_0151921012_a0b30893d3da240388885a50af44269db"></a>一个进程间通信的Socket。</p>
</td>

</tr>

<tr id="zh-cn_topic_0151921012_r954b0bbd2609438ca1ecc49402117695"><td class="cellrowborder" valign="top" width="23.18%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151921012_a2e0d25e939104ff5a1c3f79c5285689f"><a name="zh-cn_topic_0151921012_a2e0d25e939104ff5a1c3f79c5285689f"></a><a name="zh-cn_topic_0151921012_a2e0d25e939104ff5a1c3f79c5285689f"></a>Swap unit</p>
</td>

<td class="cellrowborder" valign="top" width="20.36%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151921012_af7250fd0df504b6db1ae83ea22ad4dc3"><a name="zh-cn_topic_0151921012_af7250fd0df504b6db1ae83ea22ad4dc3"></a><a name="zh-cn_topic_0151921012_af7250fd0df504b6db1ae83ea22ad4dc3"></a>.swap</p>
</td>

<td class="cellrowborder" valign="top" width="56.46%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151921012_aed1f0dc1800f457d9271ab272aaf9019"><a name="zh-cn_topic_0151921012_aed1f0dc1800f457d9271ab272aaf9019"></a><a name="zh-cn_topic_0151921012_aed1f0dc1800f457d9271ab272aaf9019"></a>swap设备或者swap文件。</p>
</td>

</tr>

<tr id="zh-cn_topic_0151921012_r27a40c4c1d7b4c74ac4913185f408b22"><td class="cellrowborder" valign="top" width="23.18%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151921012_aec67b2a244f843f59fda49a59083ecd8"><a name="zh-cn_topic_0151921012_aec67b2a244f843f59fda49a59083ecd8"></a><a name="zh-cn_topic_0151921012_aec67b2a244f843f59fda49a59083ecd8"></a>Timer unit</p>
</td>

<td class="cellrowborder" valign="top" width="20.36%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151921012_a0890a8d257014b609f9609b7d64d1535"><a name="zh-cn_topic_0151921012_a0890a8d257014b609f9609b7d64d1535"></a><a name="zh-cn_topic_0151921012_a0890a8d257014b609f9609b7d64d1535"></a>.timer</p>
</td>

<td class="cellrowborder" valign="top" width="56.46%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151921012_a907849cda16f459b9c50d4b58324ec7d"><a name="zh-cn_topic_0151921012_a907849cda16f459b9c50d4b58324ec7d"></a><a name="zh-cn_topic_0151921012_a907849cda16f459b9c50d4b58324ec7d"></a>systemd计时器。</p>
</td>

</tr>

</tbody>
</table>

所有的可用systemd unit类型，可在如[表2](#zh-cn_topic_0151921012_t2523a0a9a0c54f9b849e52d1efa0160c)所示的路径下查看。

**表 2**  可用systemd unit类型

<a name="zh-cn_topic_0151921012_t2523a0a9a0c54f9b849e52d1efa0160c"></a>
<table><thead align="left"><tr id="zh-cn_topic_0151921012_r213bb3b501954621bfa006ab9ddfbd62"><th class="cellrowborder" valign="top" width="32.33%" id="mcps1.2.3.1.1"><p id="zh-cn_topic_0151921012_afce39246edb84dd7a9aa40dff9b8c7e3"><a name="zh-cn_topic_0151921012_afce39246edb84dd7a9aa40dff9b8c7e3"></a><a name="zh-cn_topic_0151921012_afce39246edb84dd7a9aa40dff9b8c7e3"></a>路径</p>
</th>

<th class="cellrowborder" valign="top" width="67.67%" id="mcps1.2.3.1.2"><p id="zh-cn_topic_0151921012_abebe174b3f9c4ff4b28270e3f1907b5b"><a name="zh-cn_topic_0151921012_abebe174b3f9c4ff4b28270e3f1907b5b"></a><a name="zh-cn_topic_0151921012_abebe174b3f9c4ff4b28270e3f1907b5b"></a>描述</p>
</th>

</tr>

</thead>
<tbody><tr id="zh-cn_topic_0151921012_rcae60499dc8540328df0a6bf543aaafa"><td class="cellrowborder" valign="top" width="32.33%" headers="mcps1.2.3.1.1 "><p id="zh-cn_topic_0151921012_a7f7f73f64b3d4294a2f717f5a5dedd1c"><a name="zh-cn_topic_0151921012_a7f7f73f64b3d4294a2f717f5a5dedd1c"></a><a name="zh-cn_topic_0151921012_a7f7f73f64b3d4294a2f717f5a5dedd1c"></a>/usr/lib/systemd/system/</p>
</td>

<td class="cellrowborder" valign="top" width="67.67%" headers="mcps1.2.3.1.2 "><p id="zh-cn_topic_0151921012_af3744f8424524c1c864a7ff18092079d"><a name="zh-cn_topic_0151921012_af3744f8424524c1c864a7ff18092079d"></a><a name="zh-cn_topic_0151921012_af3744f8424524c1c864a7ff18092079d"></a>随安装的RPM产生的systemd units。</p>
</td>

</tr>

<tr id="zh-cn_topic_0151921012_r381a8939b45e4b419479c02bf07f0cd7"><td class="cellrowborder" valign="top" width="32.33%" headers="mcps1.2.3.1.1 "><p id="zh-cn_topic_0151921012_aabacb836c0fa4f6f96476ff465870cd0"><a name="zh-cn_topic_0151921012_aabacb836c0fa4f6f96476ff465870cd0"></a><a name="zh-cn_topic_0151921012_aabacb836c0fa4f6f96476ff465870cd0"></a>/run/systemd/system/</p>
</td>

<td class="cellrowborder" valign="top" width="67.67%" headers="mcps1.2.3.1.2 "><p id="zh-cn_topic_0151921012_a2edec0a6cd0741a0b8b067d9f9c33b98"><a name="zh-cn_topic_0151921012_a2edec0a6cd0741a0b8b067d9f9c33b98"></a><a name="zh-cn_topic_0151921012_a2edec0a6cd0741a0b8b067d9f9c33b98"></a>在运行时创建systemd units。</p>
</td>

</tr>

<tr id="zh-cn_topic_0151921012_rc0974b74cedf4b5ba85d1347bb553c14"><td class="cellrowborder" valign="top" width="32.33%" headers="mcps1.2.3.1.1 "><p id="zh-cn_topic_0151921012_a54ab3b765b2c4590a35494886586dcc3"><a name="zh-cn_topic_0151921012_a54ab3b765b2c4590a35494886586dcc3"></a><a name="zh-cn_topic_0151921012_a54ab3b765b2c4590a35494886586dcc3"></a>/etc/systemd/system/</p>
</td>

<td class="cellrowborder" valign="top" width="67.67%" headers="mcps1.2.3.1.2 "><p id="zh-cn_topic_0151921012_a9fc8f932d4ff4ba4b6c0469219073cb4"><a name="zh-cn_topic_0151921012_a9fc8f932d4ff4ba4b6c0469219073cb4"></a><a name="zh-cn_topic_0151921012_a9fc8f932d4ff4ba4b6c0469219073cb4"></a>由系统管理员创建和管理的systemd units。</p>
</td>

</tr>

</tbody>
</table>

## 特性说明

### 更快的启动速度

systemd提供了比UpStart更激进的并行启动能力，采用了socket/D-Bus activation等技术启动服务，带来了更快的启动速度。

为了减少系统启动时间，systemd的目标是：

-   尽可能启动更少的进程。
-   尽可能将更多进程并行启动。

### 提供按需启动能力

当sysvinit系统初始化的时候，它会将所有可能用到的后台服务进程全部启动运行。并且系统必须等待所有的服务都启动就绪之后，才允许用户登录。这种做法有两个缺点：首先是启动时间过长；其次是系统资源浪费。

某些服务很可能在很长一段时间内，甚至整个服务器运行期间都没有被使用过。比如CUPS，打印服务在多数服务器上很少被真正使用到。您可能没有想到，在很多服务器上SSHD也是很少被真正访问到的。花费在启动这些服务上的时间是不必要的；同样，花费在这些服务上的系统资源也是一种浪费。

systemd可以提供按需启动的能力，只有在某个服务被真正请求的时候才启动它。当该服务结束，systemd可以关闭它，等待下次需要时再次启动它。

### 采用cgroup特性跟踪和管理进程的生命周期

init系统的一个重要职责就是负责跟踪和管理服务进程的生命周期。它不仅可以启动一个服务，也能够停止服务。这看上去没有什么特别的，然而在真正用代码实现的时候，您或许会发现停止服务比一开始想的要困难。

服务进程一般都会作为守护进程（daemon）在后台运行，为此服务程序有时候会派生（fork）两次。在UpStart中，需要在配置文件中正确地配置expect小节。这样UpStart通过对fork系统调用进行计数，从而获知真正的精灵进程的PID号。

cgroup已经出现了很久，它主要用来实现系统资源配额管理。cgroup提供了类似文件系统的接口，使用方便。当进程创建子进程时，子进程会继承父进程的cgroup。因此无论服务如何启动新的子进程，所有的这些相关进程都会属于同一个cgroup，systemd只需要简单地遍历指定的cgroup即可正确地找到所有的相关进程，将它们逐一停止即可。

### 启动挂载点和自动挂载的管理

传统的Linux系统中，用户可以用/etc/fstab文件来维护固定的文件系统挂载点。这些挂载点在系统启动过程中被自动挂载，一旦启动过程结束，这些挂载点就会确保存在。这些挂载点都是对系统运行至关重要的文件系统，比如HOME目录。和sysvinit一样，systemd管理这些挂载点，以便能够在系统启动时自动挂载它们。systemd还兼容/etc/fstab文件，您可以继续使用该文件管理挂载点。

有时候用户还需要动态挂载点，比如打算访问DVD内容时，才临时执行挂载以便访问其中的内容，而不访问光盘时该挂载点被取消（umount\)，以便节约资源。传统地，人们依赖autofs服务来实现这种功能。

systemd内建了自动挂载服务，无需另外安装autofs服务，可以直接使用systemd提供的自动挂载管理能力来实现autofs的功能。

### 实现事务性依赖关系管理

系统启动过程是由很多的独立工作共同组成的，这些工作之间可能存在依赖关系，比如挂载一个NFS文件系统必须依赖网络能够正常工作。systemd虽然能够最大限度地并发执行很多有依赖关系的工作，但是类似“挂载NFS”和“启动网络”这样的工作还是存在天生的先后依赖关系，无法并发执行。对于这些任务，systemd维护一个“事务一致性”的概念，保证所有相关的服务都可以正常启动而不会出现互相依赖，以至于死锁的情况。

### 与SysV初始化脚本兼容

和UpStart一样，systemd引入了新的配置方式，对应用程序的开发也有一些新的要求。如果systemd想替代目前正在运行的初始化系统，就必须和现有程序兼容。任何一个Linux发行版都很难为了采用systemd而在短时间内将所有的服务代码都修改一遍。

systemd提供了和sysvinit以及LSB initscripts兼容的特性。系统中已经存在的服务和进程无需修改。这降低了系统向systemd迁移的成本，使得systemd替换现有初始化系统成为可能。

### 能够对系统进行快照和恢复

systemd支持按需启动，因此系统的运行状态是动态变化的，人们无法准确地知道系统当前运行了哪些服务。systemd快照提供了一种将当前系统运行状态保存并恢复的能力。

比如系统当前正运行服务A和B，可以用systemd命令行对当前系统运行状况创建快照。然后将进程A停止，或者做其他的任意的对系统的改变，比如启动新的进程C。在这些改变之后，运行systemd的快照恢复命令，就可立即将系统恢复到快照时刻的状态，即只有服务A，B在运行。一个可能的应用场景是调试：比如服务器出现一些异常，为了调试用户将当前状态保存为快照，然后可以进行任意的操作，比如停止服务等等。等调试结束，恢复快照即可。

## 管理系统服务

systemd提供systemctl命令来运行、关闭、重启、显示、启用/禁用系统服务。

### sysvinit命令和systemd命令

systemd提供systemctl命令与sysvinit命令的功能类似。当前版本中依然兼容service和chkconfig命令，相关说明如[表3](#zh-cn_topic_0151920917_ta7039963b0c74b909b72c22cbc9f2e28)，但建议用systemctl进行系统服务管理。

**表 3**  sysvinit命令和systemd命令的对照表

<a name="zh-cn_topic_0151920917_ta7039963b0c74b909b72c22cbc9f2e28"></a>
<table><thead align="left"><tr id="zh-cn_topic_0151920917_rfd1d35347f514aad968791e4f806aeae"><th class="cellrowborder" valign="top" width="30%" id="mcps1.2.4.1.1"><p id="zh-cn_topic_0151920917_a28f83d4ce4004293a41179a86a5498d6"><a name="zh-cn_topic_0151920917_a28f83d4ce4004293a41179a86a5498d6"></a><a name="zh-cn_topic_0151920917_a28f83d4ce4004293a41179a86a5498d6"></a><strong id="zh-cn_topic_0151920917_afac6005087f84c69a4175c6d4aaa1630"><a name="zh-cn_topic_0151920917_afac6005087f84c69a4175c6d4aaa1630"></a><a name="zh-cn_topic_0151920917_afac6005087f84c69a4175c6d4aaa1630"></a>sysvinit命令</strong></p>
</th>
<th class="cellrowborder" valign="top" width="37%" id="mcps1.2.4.1.2"><p id="zh-cn_topic_0151920917_a3e59af7c25ab4c08b96205eebd7df00c"><a name="zh-cn_topic_0151920917_a3e59af7c25ab4c08b96205eebd7df00c"></a><a name="zh-cn_topic_0151920917_a3e59af7c25ab4c08b96205eebd7df00c"></a><strong id="zh-cn_topic_0151920917_a02383f260a6b43d7ae72362fe1845f92"><a name="zh-cn_topic_0151920917_a02383f260a6b43d7ae72362fe1845f92"></a><a name="zh-cn_topic_0151920917_a02383f260a6b43d7ae72362fe1845f92"></a>systemd命令</strong></p>
</th>
<th class="cellrowborder" valign="top" width="33%" id="mcps1.2.4.1.3"><p id="zh-cn_topic_0151920917_a045311be27aa4014afbe4159033e3ac2"><a name="zh-cn_topic_0151920917_a045311be27aa4014afbe4159033e3ac2"></a><a name="zh-cn_topic_0151920917_a045311be27aa4014afbe4159033e3ac2"></a><strong id="zh-cn_topic_0151920917_a5fee977f7ce8485db5706e856ec7081d"><a name="zh-cn_topic_0151920917_a5fee977f7ce8485db5706e856ec7081d"></a><a name="zh-cn_topic_0151920917_a5fee977f7ce8485db5706e856ec7081d"></a>备注</strong></p>
</th>
</tr>
</thead>
<tbody><tr id="zh-cn_topic_0151920917_r2de0ab9c58c14fbb9df4fb27b6b2a6cb"><td class="cellrowborder" valign="top" width="30%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151920917_a5a2e2e920ad842969ba0cfae30934767"><a name="zh-cn_topic_0151920917_a5a2e2e920ad842969ba0cfae30934767"></a><a name="zh-cn_topic_0151920917_a5a2e2e920ad842969ba0cfae30934767"></a>service <span id="ph14591115171"><a name="ph14591115171"></a><a name="ph14591115171"></a><em id="i25691814141714"><a name="i25691814141714"></a><a name="i25691814141714"></a>network</em></span> start</p>
</td>
<td class="cellrowborder" valign="top" width="37%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151920917_a0990a28043f244f3a7c63159310ea5fc"><a name="zh-cn_topic_0151920917_a0990a28043f244f3a7c63159310ea5fc"></a><a name="zh-cn_topic_0151920917_a0990a28043f244f3a7c63159310ea5fc"></a>systemctl start <span id="ph347011919176"><a name="ph347011919176"></a><a name="ph347011919176"></a><em id="i1147010194173"><a name="i1147010194173"></a><a name="i1147010194173"></a>network</em></span>.service</p>
</td>
<td class="cellrowborder" valign="top" width="33%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151920917_a6f87a02ac1cb4b37845b6a91ba35eb02"><a name="zh-cn_topic_0151920917_a6f87a02ac1cb4b37845b6a91ba35eb02"></a><a name="zh-cn_topic_0151920917_a6f87a02ac1cb4b37845b6a91ba35eb02"></a>用来启动一个服务 (并不会重启现有的)。</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920917_r234d52fbaf2744e58e62737f22a62ee9"><td class="cellrowborder" valign="top" width="30%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151920917_a4d1be5b113c748b5a81a5898138d28d8"><a name="zh-cn_topic_0151920917_a4d1be5b113c748b5a81a5898138d28d8"></a><a name="zh-cn_topic_0151920917_a4d1be5b113c748b5a81a5898138d28d8"></a>service <span id="ph0603162191715"><a name="ph0603162191715"></a><a name="ph0603162191715"></a><em id="i76031221191716"><a name="i76031221191716"></a><a name="i76031221191716"></a>network</em></span> stop</p>
</td>
<td class="cellrowborder" valign="top" width="37%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151920917_a44b1659e2bfd463da45b05e17f4d6021"><a name="zh-cn_topic_0151920917_a44b1659e2bfd463da45b05e17f4d6021"></a><a name="zh-cn_topic_0151920917_a44b1659e2bfd463da45b05e17f4d6021"></a>systemctl stop <span id="ph15761523121713"><a name="ph15761523121713"></a><a name="ph15761523121713"></a><em id="i1176117234177"><a name="i1176117234177"></a><a name="i1176117234177"></a>network</em></span>.service</p>
</td>
<td class="cellrowborder" valign="top" width="33%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151920917_afada400adfde455aafcf5f45494e85cf"><a name="zh-cn_topic_0151920917_afada400adfde455aafcf5f45494e85cf"></a><a name="zh-cn_topic_0151920917_afada400adfde455aafcf5f45494e85cf"></a>用来停止一个服务 (并不会重启现有的)。</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920917_r7954bf07d8b24964a6fd9d102c0fbda8"><td class="cellrowborder" valign="top" width="30%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151920917_a7bcda643db174a779968a5ae5a9f7c18"><a name="zh-cn_topic_0151920917_a7bcda643db174a779968a5ae5a9f7c18"></a><a name="zh-cn_topic_0151920917_a7bcda643db174a779968a5ae5a9f7c18"></a>service <span id="ph514726191710"><a name="ph514726191710"></a><a name="ph514726191710"></a><em id="i314182613171"><a name="i314182613171"></a><a name="i314182613171"></a>network</em></span> restart</p>
</td>
<td class="cellrowborder" valign="top" width="37%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151920917_ac4319fcaf27b4960acc4025be401420d"><a name="zh-cn_topic_0151920917_ac4319fcaf27b4960acc4025be401420d"></a><a name="zh-cn_topic_0151920917_ac4319fcaf27b4960acc4025be401420d"></a>systemctl restart <span id="ph19763112781716"><a name="ph19763112781716"></a><a name="ph19763112781716"></a><em id="i2763627191712"><a name="i2763627191712"></a><a name="i2763627191712"></a>network</em></span>.service</p>
</td>
<td class="cellrowborder" valign="top" width="33%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151920917_a2b544d2a4b744822a7371b4c2d302fcd"><a name="zh-cn_topic_0151920917_a2b544d2a4b744822a7371b4c2d302fcd"></a><a name="zh-cn_topic_0151920917_a2b544d2a4b744822a7371b4c2d302fcd"></a>用来停止并启动一个服务。</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920917_r5fb05eeabf4743f6b95858329d896d77"><td class="cellrowborder" valign="top" width="30%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151920917_ab4f282845e28411e8f96b6186b6db84b"><a name="zh-cn_topic_0151920917_ab4f282845e28411e8f96b6186b6db84b"></a><a name="zh-cn_topic_0151920917_ab4f282845e28411e8f96b6186b6db84b"></a>service <span id="ph1218310313175"><a name="ph1218310313175"></a><a name="ph1218310313175"></a><em id="i5183203114173"><a name="i5183203114173"></a><a name="i5183203114173"></a>network</em></span> reload</p>
</td>
<td class="cellrowborder" valign="top" width="37%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151920917_abf350ef96d69405cae647284bfcf4ce2"><a name="zh-cn_topic_0151920917_abf350ef96d69405cae647284bfcf4ce2"></a><a name="zh-cn_topic_0151920917_abf350ef96d69405cae647284bfcf4ce2"></a>systemctl reload <span id="ph16981646181718"><a name="ph16981646181718"></a><a name="ph16981646181718"></a><em id="i8989468178"><a name="i8989468178"></a><a name="i8989468178"></a>network</em></span>.service</p>
</td>
<td class="cellrowborder" valign="top" width="33%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151920917_acf06a1fd807d49a796e2064a403448e1"><a name="zh-cn_topic_0151920917_acf06a1fd807d49a796e2064a403448e1"></a><a name="zh-cn_topic_0151920917_acf06a1fd807d49a796e2064a403448e1"></a>当支持时，重新装载配置文件而不中断等待操作。</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920917_rd496143bec874f7b943e64194f84f21e"><td class="cellrowborder" valign="top" width="30%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151920917_ac09908e607dc41be9ca836fcc1239f84"><a name="zh-cn_topic_0151920917_ac09908e607dc41be9ca836fcc1239f84"></a><a name="zh-cn_topic_0151920917_ac09908e607dc41be9ca836fcc1239f84"></a>service <span id="ph9594125510176"><a name="ph9594125510176"></a><a name="ph9594125510176"></a><em id="i8594125511173"><a name="i8594125511173"></a><a name="i8594125511173"></a>network</em></span> condrestart</p>
</td>
<td class="cellrowborder" valign="top" width="37%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151920917_af07ff7e0d19e4be2b48478bb7bc8d598"><a name="zh-cn_topic_0151920917_af07ff7e0d19e4be2b48478bb7bc8d598"></a><a name="zh-cn_topic_0151920917_af07ff7e0d19e4be2b48478bb7bc8d598"></a>systemctl condrestart <span id="ph106216761811"><a name="ph106216761811"></a><a name="ph106216761811"></a><em id="i1862127131818"><a name="i1862127131818"></a><a name="i1862127131818"></a>network</em></span>.service</p>
</td>
<td class="cellrowborder" valign="top" width="33%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151920917_a7bdfc64d030a4b42bd585516423597c2"><a name="zh-cn_topic_0151920917_a7bdfc64d030a4b42bd585516423597c2"></a><a name="zh-cn_topic_0151920917_a7bdfc64d030a4b42bd585516423597c2"></a>如果服务正在运行那么重启它。</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920917_r713e5d55a8f9431f9d3bd610a471a75b"><td class="cellrowborder" valign="top" width="30%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151920917_a3bfd99b1d31b49d78942a71f95a591b7"><a name="zh-cn_topic_0151920917_a3bfd99b1d31b49d78942a71f95a591b7"></a><a name="zh-cn_topic_0151920917_a3bfd99b1d31b49d78942a71f95a591b7"></a>service <span id="ph13933131001812"><a name="ph13933131001812"></a><a name="ph13933131001812"></a><em id="i129331410101817"><a name="i129331410101817"></a><a name="i129331410101817"></a>network</em></span> status</p>
</td>
<td class="cellrowborder" valign="top" width="37%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151920917_abcf4fcc5f3eb49e98177485d1e0fa8c8"><a name="zh-cn_topic_0151920917_abcf4fcc5f3eb49e98177485d1e0fa8c8"></a><a name="zh-cn_topic_0151920917_abcf4fcc5f3eb49e98177485d1e0fa8c8"></a>systemctl status <span id="ph216717133188"><a name="ph216717133188"></a><a name="ph216717133188"></a><em id="i14167141311818"><a name="i14167141311818"></a><a name="i14167141311818"></a>network</em></span>.service</p>
</td>
<td class="cellrowborder" valign="top" width="33%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151920917_a2edbdadf7af149a785e7bb53e742957d"><a name="zh-cn_topic_0151920917_a2edbdadf7af149a785e7bb53e742957d"></a><a name="zh-cn_topic_0151920917_a2edbdadf7af149a785e7bb53e742957d"></a><span id="ph1531113452716"><a name="ph1531113452716"></a><a name="ph1531113452716"></a>检查</span>服务<span id="ph20809162283"><a name="ph20809162283"></a><a name="ph20809162283"></a>的</span>运行<span id="ph394695587"><a name="ph394695587"></a><a name="ph394695587"></a>状态</span>。</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920917_rdbb2c99800964d3a939744820783d83e"><td class="cellrowborder" valign="top" width="30%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151920917_a532ae2e1fcee47c1b2c793af353c8497"><a name="zh-cn_topic_0151920917_a532ae2e1fcee47c1b2c793af353c8497"></a><a name="zh-cn_topic_0151920917_a532ae2e1fcee47c1b2c793af353c8497"></a>chkconfig <span id="ph1543141851814"><a name="ph1543141851814"></a><a name="ph1543141851814"></a><em id="i12543718141817"><a name="i12543718141817"></a><a name="i12543718141817"></a>network</em></span> on</p>
</td>
<td class="cellrowborder" valign="top" width="37%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151920917_ac70b593c72654611b5fb947cc4ce0be8"><a name="zh-cn_topic_0151920917_ac70b593c72654611b5fb947cc4ce0be8"></a><a name="zh-cn_topic_0151920917_ac70b593c72654611b5fb947cc4ce0be8"></a>systemctl enable <span id="ph1287512011812"><a name="ph1287512011812"></a><a name="ph1287512011812"></a><em id="i68755202187"><a name="i68755202187"></a><a name="i68755202187"></a>network</em></span>.service</p>
</td>
<td class="cellrowborder" valign="top" width="33%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151920917_af0790cedca9e4ba6815f635b0ebbeaf0"><a name="zh-cn_topic_0151920917_af0790cedca9e4ba6815f635b0ebbeaf0"></a><a name="zh-cn_topic_0151920917_af0790cedca9e4ba6815f635b0ebbeaf0"></a>在下次启动时或满足其他触发条件时设置服务为启用。</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920917_rd68859dcb33542debd6ee8ad5156b36c"><td class="cellrowborder" valign="top" width="30%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151920917_a709258a9eeee403aa92657a02bf35217"><a name="zh-cn_topic_0151920917_a709258a9eeee403aa92657a02bf35217"></a><a name="zh-cn_topic_0151920917_a709258a9eeee403aa92657a02bf35217"></a>chkconfig <span id="ph1733872714188"><a name="ph1733872714188"></a><a name="ph1733872714188"></a><em id="i103391827191816"><a name="i103391827191816"></a><a name="i103391827191816"></a>network</em></span> off</p>
</td>
<td class="cellrowborder" valign="top" width="37%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151920917_ac33b4c8bd2f24d66b4e3b818331588b1"><a name="zh-cn_topic_0151920917_ac33b4c8bd2f24d66b4e3b818331588b1"></a><a name="zh-cn_topic_0151920917_ac33b4c8bd2f24d66b4e3b818331588b1"></a>systemctl disable <span id="ph8377183211187"><a name="ph8377183211187"></a><a name="ph8377183211187"></a><em id="i83771532111817"><a name="i83771532111817"></a><a name="i83771532111817"></a>network</em></span>.service</p>
</td>
<td class="cellrowborder" valign="top" width="33%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151920917_a1845b23447a9422993c7f35412d8bccd"><a name="zh-cn_topic_0151920917_a1845b23447a9422993c7f35412d8bccd"></a><a name="zh-cn_topic_0151920917_a1845b23447a9422993c7f35412d8bccd"></a>在下次启动时或满足其他触发条件时设置服务为禁用。</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920917_r6e6a32f051694436a17223d750d3ca5d"><td class="cellrowborder" valign="top" width="30%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151920917_a7100f90dea8e4aac9ebbd1046cfe1b61"><a name="zh-cn_topic_0151920917_a7100f90dea8e4aac9ebbd1046cfe1b61"></a><a name="zh-cn_topic_0151920917_a7100f90dea8e4aac9ebbd1046cfe1b61"></a>chkconfig <span id="ph2188133731811"><a name="ph2188133731811"></a><a name="ph2188133731811"></a><em id="i20188173712184"><a name="i20188173712184"></a><a name="i20188173712184"></a>network</em></span></p>
</td>
<td class="cellrowborder" valign="top" width="37%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151920917_a1d84c3ad47164379a76dc7e895d8ec75"><a name="zh-cn_topic_0151920917_a1d84c3ad47164379a76dc7e895d8ec75"></a><a name="zh-cn_topic_0151920917_a1d84c3ad47164379a76dc7e895d8ec75"></a>systemctl is-enabled <span id="ph79191839131813"><a name="ph79191839131813"></a><a name="ph79191839131813"></a><em id="i891911394186"><a name="i891911394186"></a><a name="i891911394186"></a>network</em></span>.service</p>
</td>
<td class="cellrowborder" valign="top" width="33%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151920917_a6443c2f5c45d46098389ce04d7c4d067"><a name="zh-cn_topic_0151920917_a6443c2f5c45d46098389ce04d7c4d067"></a><a name="zh-cn_topic_0151920917_a6443c2f5c45d46098389ce04d7c4d067"></a>用来检查一个服务在当前环境下被配置为启用还是禁用。</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920917_r4714a5d93d1f4bb68bc6aad5119cffb1"><td class="cellrowborder" valign="top" width="30%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151920917_aa363ce8663604d429955880c4d56dadb"><a name="zh-cn_topic_0151920917_aa363ce8663604d429955880c4d56dadb"></a><a name="zh-cn_topic_0151920917_aa363ce8663604d429955880c4d56dadb"></a>chkconfig \-\-list</p>
</td>
<td class="cellrowborder" valign="top" width="37%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151920917_a921188067f294d718d37be90122b8e9d"><a name="zh-cn_topic_0151920917_a921188067f294d718d37be90122b8e9d"></a><a name="zh-cn_topic_0151920917_a921188067f294d718d37be90122b8e9d"></a>systemctl list-unit-files \-\-type=service</p>
</td>
<td class="cellrowborder" valign="top" width="33%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151920917_a2575b1e1d82e42178cd3ffd724ffa6c8"><a name="zh-cn_topic_0151920917_a2575b1e1d82e42178cd3ffd724ffa6c8"></a><a name="zh-cn_topic_0151920917_a2575b1e1d82e42178cd3ffd724ffa6c8"></a>输出在各个运行级别下服务的启用和禁用情况。</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920917_ref5860825d054488a966acab6382ccb3"><td class="cellrowborder" valign="top" width="30%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151920917_acd5c91b22ffe4cf5ab418a2d65820f02"><a name="zh-cn_topic_0151920917_acd5c91b22ffe4cf5ab418a2d65820f02"></a><a name="zh-cn_topic_0151920917_acd5c91b22ffe4cf5ab418a2d65820f02"></a>chkconfig <span id="ph12765194351818"><a name="ph12765194351818"></a><a name="ph12765194351818"></a><em id="i187651543191814"><a name="i187651543191814"></a><a name="i187651543191814"></a>network</em></span> \-\-list</p>
</td>
<td class="cellrowborder" valign="top" width="37%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151920917_afa513e24075d4ca7bd2348451ea1d27b"><a name="zh-cn_topic_0151920917_afa513e24075d4ca7bd2348451ea1d27b"></a><a name="zh-cn_topic_0151920917_afa513e24075d4ca7bd2348451ea1d27b"></a>ls /etc/systemd/system/*.wants/<span id="ph74001346151817"><a name="ph74001346151817"></a><a name="ph74001346151817"></a><em id="i7400164691813"><a name="i7400164691813"></a><a name="i7400164691813"></a>network</em></span>.service</p>
</td>
<td class="cellrowborder" valign="top" width="33%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151920917_a75394896b43b4c6689ca601670afda3b"><a name="zh-cn_topic_0151920917_a75394896b43b4c6689ca601670afda3b"></a><a name="zh-cn_topic_0151920917_a75394896b43b4c6689ca601670afda3b"></a>用来列出该服务在哪些运行级别下启用和禁用。</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920917_rd6c7141c6da9413db38f999f2db4c6bc"><td class="cellrowborder" valign="top" width="30%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151920917_ac75a48e757db42699bd3c7e801285334"><a name="zh-cn_topic_0151920917_ac75a48e757db42699bd3c7e801285334"></a><a name="zh-cn_topic_0151920917_ac75a48e757db42699bd3c7e801285334"></a>chkconfig <span id="ph212265219189"><a name="ph212265219189"></a><a name="ph212265219189"></a><em id="i5122352111811"><a name="i5122352111811"></a><a name="i5122352111811"></a>network</em></span> \-\-add</p>
</td>
<td class="cellrowborder" valign="top" width="37%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151920917_ab3f7243a981f4731bee057367493d1d3"><a name="zh-cn_topic_0151920917_ab3f7243a981f4731bee057367493d1d3"></a><a name="zh-cn_topic_0151920917_ab3f7243a981f4731bee057367493d1d3"></a>systemctl daemon-reload</p>
</td>
<td class="cellrowborder" valign="top" width="33%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151920917_af79feff246144baca76efe245350d793"><a name="zh-cn_topic_0151920917_af79feff246144baca76efe245350d793"></a><a name="zh-cn_topic_0151920917_af79feff246144baca76efe245350d793"></a>当您创建新服务文件或者变更设置时使用。</p>
</td>
</tr>
</tbody>
</table>

### 显示所有当前服务

如果您需要显示当前正在运行的服务，使用命令如下：

```
systemctl list-units --type service
```

如果您需要显示所有的服务（包括未运行的服务），需要添加-all参数，使用命令如下：

```
systemctl list-units --type service --all
```

例如显示当前正在运行的服务，命令如下：

```
$ systemctl list-units --type service
UNIT                        LOAD   ACTIVE     SUB     JOB   DESCRIPTION  
atd.service                 loaded active     running       Deferred execution scheduler  
auditd.service              loaded active     running       Security Auditing Service  
avahi-daemon.service        loaded active     running       Avahi mDNS/DNS-SD Stack  
chronyd.service             loaded active     running       NTP client/server  
crond.service               loaded active     running       Command Scheduler  
dbus.service                loaded active     running       D-Bus System Message Bus  
dracut-shutdown.service     loaded active     exited        Restore /run/initramfs on shutdown  
firewalld.service           loaded active     running       firewalld - dynamic firewall daemon  
getty@tty1.service          loaded active     running       Getty on tty1  
gssproxy.service            loaded active     running       GSSAPI Proxy Daemon  
irqbalance.service          loaded active     running       irqbalance daemon  
iscsid.service              loaded activating start   start Open-iSCSI
```

### 显示服务状态

如果您需要显示某个服务的状态，可执行如下命令：

```
systemctl status name.service
```

相关状态显示参数说明如[表4](#zh-cn_topic_0151920917_t36cd267d69244ed39ae06bb117ed8e62)所示。

**表 4**  状态参数说明

<a name="zh-cn_topic_0151920917_t36cd267d69244ed39ae06bb117ed8e62"></a>
<table><thead align="left"><tr id="zh-cn_topic_0151920917_r2bf0635c239b4bbeaf7bc4eb4d85459e"><th class="cellrowborder" valign="top" width="19%" id="mcps1.2.3.1.1"><p id="zh-cn_topic_0151920917_a8dde4401e621448eab369aa9ade622e4"><a name="zh-cn_topic_0151920917_a8dde4401e621448eab369aa9ade622e4"></a><a name="zh-cn_topic_0151920917_a8dde4401e621448eab369aa9ade622e4"></a><strong id="zh-cn_topic_0151920917_aeb48f5ed5fcc432db880948d03758042"><a name="zh-cn_topic_0151920917_aeb48f5ed5fcc432db880948d03758042"></a><a name="zh-cn_topic_0151920917_aeb48f5ed5fcc432db880948d03758042"></a>参数</strong></p>
</th>
<th class="cellrowborder" valign="top" width="81%" id="mcps1.2.3.1.2"><p id="zh-cn_topic_0151920917_a93c35017023145e4a3dd692445c4eb75"><a name="zh-cn_topic_0151920917_a93c35017023145e4a3dd692445c4eb75"></a><a name="zh-cn_topic_0151920917_a93c35017023145e4a3dd692445c4eb75"></a><strong id="zh-cn_topic_0151920917_a6eb01563833b4c188f1f172504b51fa8"><a name="zh-cn_topic_0151920917_a6eb01563833b4c188f1f172504b51fa8"></a><a name="zh-cn_topic_0151920917_a6eb01563833b4c188f1f172504b51fa8"></a>描述</strong></p>
</th>
</tr>
</thead>
<tbody><tr id="zh-cn_topic_0151920917_r2276fbc401e24f5e965a75e8ec40f61b"><td class="cellrowborder" valign="top" width="19%" headers="mcps1.2.3.1.1 "><p id="zh-cn_topic_0151920917_a35d67ba3f4394bd5aee0cdba9f1b5462"><a name="zh-cn_topic_0151920917_a35d67ba3f4394bd5aee0cdba9f1b5462"></a><a name="zh-cn_topic_0151920917_a35d67ba3f4394bd5aee0cdba9f1b5462"></a>Loaded</p>
</td>
<td class="cellrowborder" valign="top" width="81%" headers="mcps1.2.3.1.2 "><p id="zh-cn_topic_0151920917_ae54693b5ed144dd5ae89496a1c688eb0"><a name="zh-cn_topic_0151920917_ae54693b5ed144dd5ae89496a1c688eb0"></a><a name="zh-cn_topic_0151920917_ae54693b5ed144dd5ae89496a1c688eb0"></a>说明服务是否被加载，并显示服务对应的绝<span id="ph136921257153118"><a name="ph136921257153118"></a><a name="ph136921257153118"></a>对</span>路径以及是否启用。</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920917_r72275c1194ff4dd593d77bf34620d7bd"><td class="cellrowborder" valign="top" width="19%" headers="mcps1.2.3.1.1 "><p id="zh-cn_topic_0151920917_aba7f0a647fde4e12a202c0dd74d0c589"><a name="zh-cn_topic_0151920917_aba7f0a647fde4e12a202c0dd74d0c589"></a><a name="zh-cn_topic_0151920917_aba7f0a647fde4e12a202c0dd74d0c589"></a>Active</p>
</td>
<td class="cellrowborder" valign="top" width="81%" headers="mcps1.2.3.1.2 "><p id="zh-cn_topic_0151920917_a0a0de97e681f4218bc2ab1b2192acf56"><a name="zh-cn_topic_0151920917_a0a0de97e681f4218bc2ab1b2192acf56"></a><a name="zh-cn_topic_0151920917_a0a0de97e681f4218bc2ab1b2192acf56"></a>说明服务是否正在运行，并显示时间节点。</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920917_r5dea7cb1916a448da864f6d5ddaaed60"><td class="cellrowborder" valign="top" width="19%" headers="mcps1.2.3.1.1 "><p id="zh-cn_topic_0151920917_ae137d23b2f0f476fbfcfbf5042afcbf8"><a name="zh-cn_topic_0151920917_ae137d23b2f0f476fbfcfbf5042afcbf8"></a><a name="zh-cn_topic_0151920917_ae137d23b2f0f476fbfcfbf5042afcbf8"></a>Main PID</p>
</td>
<td class="cellrowborder" valign="top" width="81%" headers="mcps1.2.3.1.2 "><p id="zh-cn_topic_0151920917_a7627b260b2c74e43b6be78acb9c9dd97"><a name="zh-cn_topic_0151920917_a7627b260b2c74e43b6be78acb9c9dd97"></a><a name="zh-cn_topic_0151920917_a7627b260b2c74e43b6be78acb9c9dd97"></a>相应的系统服务的PID值。</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920917_r67e18953b9624b95bd4884e28ef20376"><td class="cellrowborder" valign="top" width="19%" headers="mcps1.2.3.1.1 "><p id="zh-cn_topic_0151920917_aa122289518d847cea99e32c1d22ab121"><a name="zh-cn_topic_0151920917_aa122289518d847cea99e32c1d22ab121"></a><a name="zh-cn_topic_0151920917_aa122289518d847cea99e32c1d22ab121"></a>CGroup</p>
</td>
<td class="cellrowborder" valign="top" width="81%" headers="mcps1.2.3.1.2 "><p id="zh-cn_topic_0151920917_a668e34c741a44741929beeab402bf767"><a name="zh-cn_topic_0151920917_a668e34c741a44741929beeab402bf767"></a><a name="zh-cn_topic_0151920917_a668e34c741a44741929beeab402bf767"></a>相关控制组（CGroup）的其他信息。</p>
</td>
</tr>
</tbody>
</table>

如果您需要鉴别某个服务是否运行，可执行如下命令：

```
systemctl is-active name.service
```

is-active命令的返回结果如下：

**表 5**  is-active命令的返回结果

<a name="table157842227315"></a>
<table><thead align="left"><tr id="row878417221132"><th class="cellrowborder" valign="top" width="50%" id="mcps1.2.3.1.1"><p id="p1978432212315"><a name="p1978432212315"></a><a name="p1978432212315"></a>状态</p>
</th>
<th class="cellrowborder" valign="top" width="50%" id="mcps1.2.3.1.2"><p id="p878410225314"><a name="p878410225314"></a><a name="p878410225314"></a>含义</p>
</th>
</tr>
</thead>
<tbody><tr id="row87841522439"><td class="cellrowborder" valign="top" width="50%" headers="mcps1.2.3.1.1 "><p id="p153819129412"><a name="p153819129412"></a><a name="p153819129412"></a>active(running)</p>
</td>
<td class="cellrowborder" valign="top" width="50%" headers="mcps1.2.3.1.2 "><p id="p938116129415"><a name="p938116129415"></a><a name="p938116129415"></a>有一只或多只程序正在系统中执行</p>
</td>
</tr>
<tr id="row7784112217315"><td class="cellrowborder" valign="top" width="50%" headers="mcps1.2.3.1.1 "><p id="p153829121246"><a name="p153829121246"></a><a name="p153829121246"></a>active(exited)</p>
</td>
<td class="cellrowborder" valign="top" width="50%" headers="mcps1.2.3.1.2 "><p id="p103822012844"><a name="p103822012844"></a><a name="p103822012844"></a>仅执行一次就正常结束的服务，目前并没有任何程序在系统中执行。 举例来说，开机或者 是挂载时才会进行一次的 quotaon 功能</p>
</td>
</tr>
<tr id="row978416227312"><td class="cellrowborder" valign="top" width="50%" headers="mcps1.2.3.1.1 "><p id="p1838251219416"><a name="p1838251219416"></a><a name="p1838251219416"></a>active(waiting)</p>
</td>
<td class="cellrowborder" valign="top" width="50%" headers="mcps1.2.3.1.2 "><p id="p23822129416"><a name="p23822129416"></a><a name="p23822129416"></a>正在执行当中，不过要等待其他的事件才能继续处理。例如：打印的队列相关服务 就是这种状态，虽然正在启动中，不过也需要真的有队列进来 (打印作业) 这样他才会继续唤醒打印机 服务来进行下一步打印的功能</p>
</td>
</tr>
<tr id="row10784102216316"><td class="cellrowborder" valign="top" width="50%" headers="mcps1.2.3.1.1 "><p id="p13382171211418"><a name="p13382171211418"></a><a name="p13382171211418"></a>inactive</p>
</td>
<td class="cellrowborder" valign="top" width="50%" headers="mcps1.2.3.1.2 "><p id="p1338217126410"><a name="p1338217126410"></a><a name="p1338217126410"></a>这个服务没有运行</p>
</td>
</tr>
</tbody>
</table>

同样，如果您需要判断某个服务是否被启用，可执行如下命令：

```
systemctl is-enabled name.service
```

is-enabled命令的返回结果如下：

**表 6**  is-enabled命令的返回结果

<a name="table105177355318"></a>
<table><thead align="left"><tr id="row9517635538"><th class="cellrowborder" valign="top" width="32.48%" id="mcps1.2.3.1.1"><p id="p551716356313"><a name="p551716356313"></a><a name="p551716356313"></a>状态</p>
</th>
<th class="cellrowborder" valign="top" width="67.52%" id="mcps1.2.3.1.2"><p id="p1051716351935"><a name="p1051716351935"></a><a name="p1051716351935"></a>含义</p>
</th>
</tr>
</thead>
<tbody><tr id="row195171351134"><td class="cellrowborder" valign="top" width="32.48%" headers="mcps1.2.3.1.1 "><p id="p165171351231"><a name="p165171351231"></a><a name="p165171351231"></a>"enabled"</p>
</td>
<td class="cellrowborder" valign="top" width="67.52%" headers="mcps1.2.3.1.2 "><p id="p155175351731"><a name="p155175351731"></a><a name="p155175351731"></a>已经通过 /etc/systemd/system/ 目录下的 Alias= 别名、 .wants/ 或 .requires/ 软连接被永久启用。</p>
</td>
</tr>
<tr id="row95171335339"><td class="cellrowborder" valign="top" width="32.48%" headers="mcps1.2.3.1.1 "><p id="p1951717351433"><a name="p1951717351433"></a><a name="p1951717351433"></a>"enabled-runtime"</p>
</td>
<td class="cellrowborder" valign="top" width="67.52%" headers="mcps1.2.3.1.2 "><p id="p9517135835"><a name="p9517135835"></a><a name="p9517135835"></a>已经通过 /run/systemd/system/ 目录下的 Alias= 别名、 .wants/ 或 .requires/ 软连接被临时启用。</p>
</td>
</tr>
<tr id="row7517143515314"><td class="cellrowborder" valign="top" width="32.48%" headers="mcps1.2.3.1.1 "><p id="p125176351137"><a name="p125176351137"></a><a name="p125176351137"></a>"linked"</p>
</td>
<td class="cellrowborder" valign="top" width="67.52%" headers="mcps1.2.3.1.2 "><p id="p145171535934"><a name="p145171535934"></a><a name="p145171535934"></a>虽然单元文件本身不在标准单元目录中，但是指向此单元文件的一个或多个软连接已经存在于 /etc/systemd/system/ 永久目录中。</p>
</td>
</tr>
<tr id="row125176351137"><td class="cellrowborder" valign="top" width="32.48%" headers="mcps1.2.3.1.1 "><p id="p2051718353313"><a name="p2051718353313"></a><a name="p2051718353313"></a>"linked-runtime"</p>
</td>
<td class="cellrowborder" valign="top" width="67.52%" headers="mcps1.2.3.1.2 "><p id="p115171835936"><a name="p115171835936"></a><a name="p115171835936"></a>虽然单元文件本身不在标准单元目录中，但是指向此单元文件的一个或多个软连接已经存在于 /run/systemd/system/ 临时目录中。</p>
</td>
</tr>
<tr id="row851719352312"><td class="cellrowborder" valign="top" width="32.48%" headers="mcps1.2.3.1.1 "><p id="p1651753520319"><a name="p1651753520319"></a><a name="p1651753520319"></a>"masked"</p>
</td>
<td class="cellrowborder" valign="top" width="67.52%" headers="mcps1.2.3.1.2 "><p id="p25171351233"><a name="p25171351233"></a><a name="p25171351233"></a>已经被 /etc/systemd/system/ 目录永久屏蔽(软连接指向 /dev/null 文件)，因此 <strong id="b1842717120514"><a name="b1842717120514"></a><a name="b1842717120514"></a>start</strong> 操作会失败。</p>
</td>
</tr>
<tr id="row551715351136"><td class="cellrowborder" valign="top" width="32.48%" headers="mcps1.2.3.1.1 "><p id="p175178351334"><a name="p175178351334"></a><a name="p175178351334"></a>"masked-runtime"</p>
</td>
<td class="cellrowborder" valign="top" width="67.52%" headers="mcps1.2.3.1.2 "><p id="p135171135138"><a name="p135171135138"></a><a name="p135171135138"></a>已经被 /run/systemd/systemd/ 目录临时屏蔽(软连接指向 /dev/null 文件)，因此 <strong id="b151231818857"><a name="b151231818857"></a><a name="b151231818857"></a>start</strong> 操作会失败。</p>
</td>
</tr>
<tr id="row35171935533"><td class="cellrowborder" valign="top" width="32.48%" headers="mcps1.2.3.1.1 "><p id="p751714351231"><a name="p751714351231"></a><a name="p751714351231"></a>"static"</p>
</td>
<td class="cellrowborder" valign="top" width="67.52%" headers="mcps1.2.3.1.2 "><p id="p551718355313"><a name="p551718355313"></a><a name="p551718355313"></a>尚未被启用，并且单元文件的 "[Install]" 小节中没有可用于 <strong id="b434102320518"><a name="b434102320518"></a><a name="b434102320518"></a>enable</strong> 命令的选项。</p>
</td>
</tr>
<tr id="row1012314171440"><td class="cellrowborder" valign="top" width="32.48%" headers="mcps1.2.3.1.1 "><p id="p131245179420"><a name="p131245179420"></a><a name="p131245179420"></a>"indirect"</p>
</td>
<td class="cellrowborder" valign="top" width="67.52%" headers="mcps1.2.3.1.2 "><p id="p91241717648"><a name="p91241717648"></a><a name="p91241717648"></a>尚未被启用，但是单元文件的 "[Install]" 小节中 Also= 选项的值列表非空(也就是列表中的某些单元可能已被启用)、或者它拥有一个不在 Also= 列表中的其他名称的别名软连接。对于模版单元来说，表示已经启用了一个不同于 DefaultInstance= 的实例。</p>
</td>
</tr>
<tr id="row123141521241"><td class="cellrowborder" valign="top" width="32.48%" headers="mcps1.2.3.1.1 "><p id="p831417211244"><a name="p831417211244"></a><a name="p831417211244"></a>"disabled"</p>
</td>
<td class="cellrowborder" valign="top" width="67.52%" headers="mcps1.2.3.1.2 "><p id="p531419213418"><a name="p531419213418"></a><a name="p531419213418"></a>尚未被启用，但是单元文件的 "[Install]" 小节中存在可用于 <strong id="b7155236854"><a name="b7155236854"></a><a name="b7155236854"></a>enable</strong> 命令的选项</p>
</td>
</tr>
<tr id="row173149216411"><td class="cellrowborder" valign="top" width="32.48%" headers="mcps1.2.3.1.1 "><p id="p83159211343"><a name="p83159211343"></a><a name="p83159211343"></a>"generated"</p>
</td>
<td class="cellrowborder" valign="top" width="67.52%" headers="mcps1.2.3.1.2 "><p id="p43151219416"><a name="p43151219416"></a><a name="p43151219416"></a>单元文件是被单元生成器动态生成的。被生成的单元文件可能并未被直接启用，而是被单元生成器隐含的启用了。</p>
</td>
</tr>
<tr id="row37625251844"><td class="cellrowborder" valign="top" width="32.48%" headers="mcps1.2.3.1.1 "><p id="p57620251419"><a name="p57620251419"></a><a name="p57620251419"></a>"transient"</p>
</td>
<td class="cellrowborder" valign="top" width="67.52%" headers="mcps1.2.3.1.2 "><p id="p127638251244"><a name="p127638251244"></a><a name="p127638251244"></a>单元文件是被运行时API动态临时生成的。该临时单元可能并未被启用。</p>
</td>
</tr>
<tr id="row57631925642"><td class="cellrowborder" valign="top" width="32.48%" headers="mcps1.2.3.1.1 "><p id="p876316256412"><a name="p876316256412"></a><a name="p876316256412"></a>"bad"</p>
</td>
<td class="cellrowborder" valign="top" width="67.52%" headers="mcps1.2.3.1.2 "><p id="p187635255419"><a name="p187635255419"></a><a name="p187635255419"></a>单元文件不正确或者出现其他错误。 <strong id="b133269534515"><a name="b133269534515"></a><a name="b133269534515"></a>is-enabled</strong> 不会返回此状态，而是会显示一条出错信息。 <strong id="b332611531751"><a name="b332611531751"></a><a name="b332611531751"></a>list-unit-files</strong> 命令有可能会显示此单元。</p>
</td>
</tr>
</tbody>
</table>

例如查看gdm.service服务状态，命令如下：

```
# systemctl status gdm.service
gdm.service - GNOME Display Manager   Loaded: loaded (/usr/lib/systemd/system/gdm.service; enabled)   Active: active (running) since Thu 2013-10-17 17:31:23 CEST; 5min ago
 Main PID: 1029 (gdm)
   CGroup: /system.slice/gdm.service
           ├─1029 /usr/sbin/gdm
           ├─1037 /usr/libexec/gdm-simple-slave --display-id /org/gno...           
           └─1047 /usr/bin/Xorg :0 -background none -verbose -auth /r...Oct 17 17:31:23 localhost systemd[1]: Started GNOME Display Manager.
```

### 运行服务

如果您需要运行某个服务，请在root权限下执行如下命令：

```
systemctl start name.service
```

例如运行httpd服务，命令如下：

```
# systemctl start httpd.service
```

### 关闭服务

如果您需要关闭某个服务，请在root权限下执行如下命令：

```
systemctl stop name.service
```

例如关闭蓝牙服务，命令如下：

```
# systemctl stop bluetooth.service
```

### 重启服务

如果您需要重启某个服务，请在root权限下执行如下命令：

```
systemctl restart name.service
```

执行命令后，当前服务会被关闭，但马上重新启动。如果您指定的服务，当前处于关闭状态，执行命令后，服务也会被启动。

例如重启蓝牙服务，命令如下：

```
# systemctl restart bluetooth.service
```

### 启用服务

如果您需要在开机时启用某个服务，请在root权限下执行如下命令：

```
systemctl enable name.service
```

例如设置httpd服务开机时启动，命令如下：

```
# systemctl enable httpd.service
ln -s '/usr/lib/systemd/system/httpd.service' '/etc/systemd/system/multi-user.target.wants/httpd.service'
```

### 禁用服务

如果您需要在开机时禁用某个服务，请在root权限下执行如下命令：

```
systemctl disable name.service
```

例如在开机时禁用蓝牙服务启动，命令如下：

```
# systemctl disable bluetooth.service
Removed /etc/systemd/system/bluetooth.target.wants/bluetooth.service.
Removed /etc/systemd/system/dbus-org.bluez.service.
```

## 改变运行级别

### Target和运行级别

systemd用目标（target）替代了运行级别的概念，提供了更大的灵活性，如您可以继承一个已有的目标，并添加其他服务，来创建自己的目标。[表7](#zh-cn_topic_0151920939_t9af92c282ad240ea9a79fb08d26e8181)列举了systemd下的目标和常见runlevel的对应关系。

**表 7**  运行级别和systemd目标

<a name="zh-cn_topic_0151920939_t9af92c282ad240ea9a79fb08d26e8181"></a>
<table><thead align="left"><tr id="zh-cn_topic_0151920939_r6198e54b95054c25ad4cbf7f6a4d94a8"><th class="cellrowborder" valign="top" width="13.389999999999999%" id="mcps1.2.4.1.1"><p id="zh-cn_topic_0151920939_a8ca063ccd2b5493eaba60d772b3a210e"><a name="zh-cn_topic_0151920939_a8ca063ccd2b5493eaba60d772b3a210e"></a><a name="zh-cn_topic_0151920939_a8ca063ccd2b5493eaba60d772b3a210e"></a>运行级别</p>
</th>
<th class="cellrowborder" valign="top" width="31.53%" id="mcps1.2.4.1.2"><p id="zh-cn_topic_0151920939_ae345f9616c9e4b99b91537e14bf301fc"><a name="zh-cn_topic_0151920939_ae345f9616c9e4b99b91537e14bf301fc"></a><a name="zh-cn_topic_0151920939_ae345f9616c9e4b99b91537e14bf301fc"></a>systemd目标（target）</p>
</th>
<th class="cellrowborder" valign="top" width="55.08%" id="mcps1.2.4.1.3"><p id="zh-cn_topic_0151920939_a51d30f31c3494031a3cb05ad3f0f83b0"><a name="zh-cn_topic_0151920939_a51d30f31c3494031a3cb05ad3f0f83b0"></a><a name="zh-cn_topic_0151920939_a51d30f31c3494031a3cb05ad3f0f83b0"></a>描述</p>
</th>
</tr>
</thead>
<tbody><tr id="zh-cn_topic_0151920939_rf26e9f9e50504c07a370b9dc87a197c9"><td class="cellrowborder" valign="top" width="13.389999999999999%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151920939_a6d80989a801f4bf4bb4546c17a7b3a33"><a name="zh-cn_topic_0151920939_a6d80989a801f4bf4bb4546c17a7b3a33"></a><a name="zh-cn_topic_0151920939_a6d80989a801f4bf4bb4546c17a7b3a33"></a>0</p>
</td>
<td class="cellrowborder" valign="top" width="31.53%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151920939_a7d9fff8415094170a9f174a1dc243183"><a name="zh-cn_topic_0151920939_a7d9fff8415094170a9f174a1dc243183"></a><a name="zh-cn_topic_0151920939_a7d9fff8415094170a9f174a1dc243183"></a>runlevel0.target，poweroff.target</p>
</td>
<td class="cellrowborder" valign="top" width="55.08%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151920939_a70514fee2f27437cbae934e8c574f997"><a name="zh-cn_topic_0151920939_a70514fee2f27437cbae934e8c574f997"></a><a name="zh-cn_topic_0151920939_a70514fee2f27437cbae934e8c574f997"></a>关闭系统。</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920939_r1e5afff728cc4151b419680f76671293"><td class="cellrowborder" valign="top" width="13.389999999999999%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151920939_a6bed301641504e7691830451ccd13084"><a name="zh-cn_topic_0151920939_a6bed301641504e7691830451ccd13084"></a><a name="zh-cn_topic_0151920939_a6bed301641504e7691830451ccd13084"></a>1<span id="ph14312164910584"><a name="ph14312164910584"></a><a name="ph14312164910584"></a>, s,</span> single</p>
</td>
<td class="cellrowborder" valign="top" width="31.53%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151920939_af07325c424aa41fd91422796a8c5530a"><a name="zh-cn_topic_0151920939_af07325c424aa41fd91422796a8c5530a"></a><a name="zh-cn_topic_0151920939_af07325c424aa41fd91422796a8c5530a"></a>runlevel1.target，rescue.target</p>
</td>
<td class="cellrowborder" valign="top" width="55.08%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151920939_a835efcb9d2ec42219ba2cf84f320006d"><a name="zh-cn_topic_0151920939_a835efcb9d2ec42219ba2cf84f320006d"></a><a name="zh-cn_topic_0151920939_a835efcb9d2ec42219ba2cf84f320006d"></a>单用户模式。</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920939_re1071d4eed334f439f54040112b05c4a"><td class="cellrowborder" valign="top" width="13.389999999999999%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151920939_zh-cn_topic_0072985277_p188013479275"><a name="zh-cn_topic_0151920939_zh-cn_topic_0072985277_p188013479275"></a><a name="zh-cn_topic_0151920939_zh-cn_topic_0072985277_p188013479275"></a>2<span id="ph60616175913"><a name="ph60616175913"></a><a name="ph60616175913"></a>, 4</span></p>
</td>
<td class="cellrowborder" valign="top" width="31.53%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151920939_a97565d2aa66a42bba4e87bd5a75413e8"><a name="zh-cn_topic_0151920939_a97565d2aa66a42bba4e87bd5a75413e8"></a><a name="zh-cn_topic_0151920939_a97565d2aa66a42bba4e87bd5a75413e8"></a>runlevel2.target，<span id="ph1462165011"><a name="ph1462165011"></a><a name="ph1462165011"></a>runlevel4.target，</span>multi-user.target</p>
</td>
<td class="cellrowborder" valign="top" width="55.08%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151920939_a99315964c38d404585856756e975fbfd"><a name="zh-cn_topic_0151920939_a99315964c38d404585856756e975fbfd"></a><a name="zh-cn_topic_0151920939_a99315964c38d404585856756e975fbfd"></a>用户定义/域特定运行级别。默认等同于3。</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920939_rb065a846486b406690e8c4224a0a0ac9"><td class="cellrowborder" valign="top" width="13.389999999999999%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151920939_zh-cn_topic_0072985277_p680154702718"><a name="zh-cn_topic_0151920939_zh-cn_topic_0072985277_p680154702718"></a><a name="zh-cn_topic_0151920939_zh-cn_topic_0072985277_p680154702718"></a>3</p>
</td>
<td class="cellrowborder" valign="top" width="31.53%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151920939_a0180d9e5e866452ebd0ec8be94dc4f05"><a name="zh-cn_topic_0151920939_a0180d9e5e866452ebd0ec8be94dc4f05"></a><a name="zh-cn_topic_0151920939_a0180d9e5e866452ebd0ec8be94dc4f05"></a>runlevel3.target，multi-user.target</p>
</td>
<td class="cellrowborder" valign="top" width="55.08%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151920939_a9c5a2a48aa5d49bf8e86a1cce1711303"><a name="zh-cn_topic_0151920939_a9c5a2a48aa5d49bf8e86a1cce1711303"></a><a name="zh-cn_topic_0151920939_a9c5a2a48aa5d49bf8e86a1cce1711303"></a>多用户，非图形化。用户可以通过多个控制台或网络登录。</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920939_r0184cfc9111840b6be09d7621237f91b"><td class="cellrowborder" valign="top" width="13.389999999999999%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151920939_aecd758e276a34d828c7f57d56aba812d"><a name="zh-cn_topic_0151920939_aecd758e276a34d828c7f57d56aba812d"></a><a name="zh-cn_topic_0151920939_aecd758e276a34d828c7f57d56aba812d"></a>5</p>
</td>
<td class="cellrowborder" valign="top" width="31.53%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151920939_a0519be8c47be4ec4a47bd2942ebdee20"><a name="zh-cn_topic_0151920939_a0519be8c47be4ec4a47bd2942ebdee20"></a><a name="zh-cn_topic_0151920939_a0519be8c47be4ec4a47bd2942ebdee20"></a>runlevel5.target，graphical.target</p>
</td>
<td class="cellrowborder" valign="top" width="55.08%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151920939_ad3463085cd604e0081dfffaa13efdad9"><a name="zh-cn_topic_0151920939_ad3463085cd604e0081dfffaa13efdad9"></a><a name="zh-cn_topic_0151920939_ad3463085cd604e0081dfffaa13efdad9"></a>多用户，图形化。通常为所有运行级别3的服务外加图形化登录。</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920939_rdd9338b99fb2419fa9257a7a21e2774f"><td class="cellrowborder" valign="top" width="13.389999999999999%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151920939_a7564c4a239924b33af88cbb8a34ec8dc"><a name="zh-cn_topic_0151920939_a7564c4a239924b33af88cbb8a34ec8dc"></a><a name="zh-cn_topic_0151920939_a7564c4a239924b33af88cbb8a34ec8dc"></a>6</p>
</td>
<td class="cellrowborder" valign="top" width="31.53%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151920939_a86730dd7a4054dedbfd4562630d462e5"><a name="zh-cn_topic_0151920939_a86730dd7a4054dedbfd4562630d462e5"></a><a name="zh-cn_topic_0151920939_a86730dd7a4054dedbfd4562630d462e5"></a>runlevel6.target，reboot.target</p>
</td>
<td class="cellrowborder" valign="top" width="55.08%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151920939_a473a6a5eca6c4b60a880ce8da3222f83"><a name="zh-cn_topic_0151920939_a473a6a5eca6c4b60a880ce8da3222f83"></a><a name="zh-cn_topic_0151920939_a473a6a5eca6c4b60a880ce8da3222f83"></a>重启系统。</p>
</td>
</tr>
<tr id="row13256325195913"><td class="cellrowborder" valign="top" width="13.389999999999999%" headers="mcps1.2.4.1.1 "><p id="p625642510595"><a name="p625642510595"></a><a name="p625642510595"></a><span id="ph122241428185918"><a name="ph122241428185918"></a><a name="ph122241428185918"></a>emergency</span></p>
</td>
<td class="cellrowborder" valign="top" width="31.53%" headers="mcps1.2.4.1.2 "><p id="p1384413745917"><a name="p1384413745917"></a><a name="p1384413745917"></a>emergency.target</p>
</td>
<td class="cellrowborder" valign="top" width="55.08%" headers="mcps1.2.4.1.3 "><p id="p92561925185919"><a name="p92561925185919"></a><a name="p92561925185919"></a><span id="ph810855365915"><a name="ph810855365915"></a><a name="ph810855365915"></a>紧急Shell</span></p>
</td>
</tr>
</tbody>
</table>

### 查看系统默认启动目标

查看当前系统默认的启动目标，命令如下：

```
systemctl get-default
```

### 查看当前系统所有的启动目标

查看当前系统所有的启动目标，命令如下：

```
systemctl list-units --type=target
```

### 改变默认目标

改变系统默认的目标，在root权限下执行如下命令：

```
systemctl set-default name.target
```

### 改变当前目标

改变当前系统的目标，在root权限下执行如下命令：

```
systemctl isolate name.target
```

### 切换到救援模式

改变当前系统为救援模式，在root权限下执行如下命令：

```
systemctl rescue
```

这条命令和“systemctl isolate rescue.target”类似。命令执行后会在串口有如下打印信息：

```
You are in rescue mode. After logging in, type "journalctl -xb" to viewsystem logs, "systemctl reboot" to reboot, "systemctl default" or "exit"to boot into default mode.
Give root password for maintenance
(or press Control-D to continue):
```

>![](public_sys-resources/icon-note.gif) **说明：**   
>用户需要重启系统，从救援模式进入正常模式。  

### 切换到紧急模式

改变当前系统为紧急模式，在root权限下执行如下命令：

```
systemctl emergency
```

这条命令和“systemctl isolate emergency.target”类似。命令执行后会在串口有如下打印信息：

```
You are in emergency mode. After logging in, type "journalctl -xb" to viewsystem logs, "systemctl reboot" to reboot, "systemctl default" or "exit"to boot into default mode.
Give root password for maintenance
(or press Control-D to continue):
```

>![](public_sys-resources/icon-note.gif) **说明：**   
>用户需要重启系统，从紧急模式进入正常模式。  

## 关闭、暂停和休眠系统

### systemctl命令

systemd通过systemctl命令可以对系统进行关机、重启、休眠等一系列操作。当前仍兼容部分Linux常用管理命令，对应关系如[表8](#zh-cn_topic_0151920964_t3daaaba6a03b4c36be9668efcdb61f3b)。建议用户使用systemctl命令进行操作。

**表 8**  命令对应关系

<a name="zh-cn_topic_0151920964_t3daaaba6a03b4c36be9668efcdb61f3b"></a>
<table><thead align="left"><tr id="zh-cn_topic_0151920964_r8e883e3ea8fd4bfe835dac3154666bfd"><th class="cellrowborder" valign="top" width="27.69276927692769%" id="mcps1.2.4.1.1"><p id="zh-cn_topic_0151920964_affa97759370e4199bee6b37a54620de8"><a name="zh-cn_topic_0151920964_affa97759370e4199bee6b37a54620de8"></a><a name="zh-cn_topic_0151920964_affa97759370e4199bee6b37a54620de8"></a><span id="ph4522150105713"><a name="ph4522150105713"></a><a name="ph4522150105713"></a>Linux常用管理</span>命令</p>
</th>
<th class="cellrowborder" valign="top" width="38.97389738973897%" id="mcps1.2.4.1.2"><p id="zh-cn_topic_0151920964_a74833d21addd43428693aba25495ea5e"><a name="zh-cn_topic_0151920964_a74833d21addd43428693aba25495ea5e"></a><a name="zh-cn_topic_0151920964_a74833d21addd43428693aba25495ea5e"></a>systemctl命令</p>
</th>
<th class="cellrowborder" valign="top" width="33.33333333333333%" id="mcps1.2.4.1.3"><p id="zh-cn_topic_0151920964_a96c730244eaa417f932cd978d244b817"><a name="zh-cn_topic_0151920964_a96c730244eaa417f932cd978d244b817"></a><a name="zh-cn_topic_0151920964_a96c730244eaa417f932cd978d244b817"></a>描述</p>
</th>
</tr>
</thead>
<tbody><tr id="zh-cn_topic_0151920964_r088f89c8dd43418bb576a2b80963402d"><td class="cellrowborder" valign="top" width="27.69276927692769%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151920964_ad51772983856400792c77b80694b2910"><a name="zh-cn_topic_0151920964_ad51772983856400792c77b80694b2910"></a><a name="zh-cn_topic_0151920964_ad51772983856400792c77b80694b2910"></a>halt</p>
</td>
<td class="cellrowborder" valign="top" width="38.97389738973897%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151920964_ab7a0cde876c74144b333192a6711037f"><a name="zh-cn_topic_0151920964_ab7a0cde876c74144b333192a6711037f"></a><a name="zh-cn_topic_0151920964_ab7a0cde876c74144b333192a6711037f"></a>systemctl halt</p>
</td>
<td class="cellrowborder" valign="top" width="33.33333333333333%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151920964_ae55b9739eb8f407a8eb672f146f01db2"><a name="zh-cn_topic_0151920964_ae55b9739eb8f407a8eb672f146f01db2"></a><a name="zh-cn_topic_0151920964_ae55b9739eb8f407a8eb672f146f01db2"></a>关闭系统</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920964_r32060b64b8684bfda592c954f3b0a451"><td class="cellrowborder" valign="top" width="27.69276927692769%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151920964_a0b98bb5ee6b444f2907e601c8a769960"><a name="zh-cn_topic_0151920964_a0b98bb5ee6b444f2907e601c8a769960"></a><a name="zh-cn_topic_0151920964_a0b98bb5ee6b444f2907e601c8a769960"></a>poweroff</p>
</td>
<td class="cellrowborder" valign="top" width="38.97389738973897%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151920964_a0b8755b08ffb4d2da8bd9e1c23bba8a9"><a name="zh-cn_topic_0151920964_a0b8755b08ffb4d2da8bd9e1c23bba8a9"></a><a name="zh-cn_topic_0151920964_a0b8755b08ffb4d2da8bd9e1c23bba8a9"></a>systemctl poweroff</p>
</td>
<td class="cellrowborder" valign="top" width="33.33333333333333%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151920964_a0a93593a65134bf9a6adc404eca43b5d"><a name="zh-cn_topic_0151920964_a0a93593a65134bf9a6adc404eca43b5d"></a><a name="zh-cn_topic_0151920964_a0a93593a65134bf9a6adc404eca43b5d"></a>关闭电源</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920964_rc44a19bda3f24ea3969e224b28e5400d"><td class="cellrowborder" valign="top" width="27.69276927692769%" headers="mcps1.2.4.1.1 "><p id="zh-cn_topic_0151920964_a9c6bf9b686b84e05b5bf465d925cb8b9"><a name="zh-cn_topic_0151920964_a9c6bf9b686b84e05b5bf465d925cb8b9"></a><a name="zh-cn_topic_0151920964_a9c6bf9b686b84e05b5bf465d925cb8b9"></a>reboot</p>
</td>
<td class="cellrowborder" valign="top" width="38.97389738973897%" headers="mcps1.2.4.1.2 "><p id="zh-cn_topic_0151920964_a246d6cb896454110aad9838aeb055198"><a name="zh-cn_topic_0151920964_a246d6cb896454110aad9838aeb055198"></a><a name="zh-cn_topic_0151920964_a246d6cb896454110aad9838aeb055198"></a>systemctl reboot</p>
</td>
<td class="cellrowborder" valign="top" width="33.33333333333333%" headers="mcps1.2.4.1.3 "><p id="zh-cn_topic_0151920964_a14f63a55961440c98d20cafe61072b30"><a name="zh-cn_topic_0151920964_a14f63a55961440c98d20cafe61072b30"></a><a name="zh-cn_topic_0151920964_a14f63a55961440c98d20cafe61072b30"></a>重启</p>
</td>
</tr>
</tbody>
</table>

### 关闭系统

关闭系统并下电，在root权限下执行如下命令：

```
systemctl poweroff
```

关闭系统但不下电机器，在root权限下执行如下命令：

```
systemctl halt
```

执行上述命令会给当前所有的登录用户发送一条提示消息。如果不想让systemd发送该消息，您可以添加“\-\-no\-wall”参数。具体命令如下：

```
systemctl --no-wall poweroff
```

### 重启系统

重启系统，在root权限下执行如下命令：

```
systemctl reboot
```

执行上述命令会给当前所有的登录用户发送一条提示消息。如果不想让systemd发送该消息，您可以添加“\-\-no\-wall”参数。具体命令如下：

```
systemctl --no-wall reboot
```

### 使系统待机

使系统待机，在root权限下执行如下命令：

```
systemctl suspend
```

### 使系统休眠

使系统休眠，在root权限下执行如下命令：

```
systemctl hibernate
```

使系统待机且处于休眠状态，在root权限下执行如下命令：

```
systemctl hybrid-sleep
```
